@@ -22,6 +22,7 @@ licence['en']="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+python3safe=True
 import dbus
 from PyQt4.QtCore import *
 import ownedUsbDisk
@@ -56,7 +57,6 @@ class DeviceListener:
             pathUDisks=self.vfatUsbPath(d)
             if pathUDisks:
                 self.connectedVolumes[pathUDisks]=d
-        ## print "at init:", self.connectedVolumes
         return
     
     def cbAdd(self, path):
@@ -67,7 +67,6 @@ class DeviceListener:
         key=self.vfatUsbPath(path)
         if key:
             self.connectedVolumes[key]=path
-            ## print "in cbAdd", self.connectedVolumes
             if self.widget:
                 self.widget.emit(SIGNAL("deviceAdded(QString)"), key)
         return
@@ -78,9 +77,8 @@ class DeviceListener:
         @param path un chemin de type UDisks vers une partition
         """
         key=self.vfatUsbPath(path)
-        if key and not self.connectedVolumes.has_key(key):
+        if key and not key in self.connectedVolumes:
             self.connectedVolumes[key]=path
-            ## print "in cbChange", self.connectedVolumes
             if self.widget:
                 self.widget.emit(SIGNAL("deviceAdded(QString)"), key)
         return
@@ -92,11 +90,10 @@ class DeviceListener:
         @param path un chemin de type UDisks vers une partition
         """
         key=str(path)
-        if self.connectedVolumes.has_key(key):
+        if key in self.connectedVolumes:
             if self.widget:
                 self.widget.emit(SIGNAL("deviceRemoved(QString)"), key)
                 self.connectedVolumes.pop(key)
-            ## print "in cbDel", self.connectedVolumes
         return
 
     def vfatUsbPath(self, dev):
