@@ -161,7 +161,7 @@ p, li { white-space: pre-wrap; }
         <translation>Continue...</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="282"/>
+        <location filename="../mainWindow.py" line="276"/>
         <source>Double-clic non pris en compte</source>
         <translation>Double click is ignored</translation>
     </message>
@@ -186,7 +186,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">No selected file</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="485"/>
+        <location filename="../mainWindow.py" line="479"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation>Please choose at least one file</translation>
     </message>
@@ -201,7 +201,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Choose files to copy from the pluggable media</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="481"/>
+        <location filename="../mainWindow.py" line="475"/>
         <source>Choix de la destination ...</source>
         <translation>Choose destination...</translation>
     </message>
@@ -211,7 +211,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Choose a destination directory</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="518"/>
         <source>Voir les copies</source>
         <translation>See the copies</translation>
     </message>
@@ -221,12 +221,12 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Do you want to see the copied files?</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="532"/>
+        <location filename="../mainWindow.py" line="526"/>
         <source>Destination manquante</source>
         <translation>Missing destination</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="532"/>
+        <location filename="../mainWindow.py" line="526"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation>Please choose a destination to copy the files</translation>
     </message>
@@ -343,7 +343,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../copyToDialog1.py" line="164"/>
         <source>%s kilo-octets</source>
-        <translation>%S kBytes</translation>
+        <translation>%s kBytes</translation>
     </message>
     <message>
         <location filename="../copyToDialog1.py" line="7274256"/>
@@ -356,7 +356,7 @@ p, li { white-space: pre-wrap; }
         <translation>%s GBytes</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="170"/>
+        <location filename="../ownedUsbDisk.py" line="168"/>
         <source>inconnu</source>
         <translation>**unknown**</translation>
     </message>
@@ -366,12 +366,12 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">The medium %1&lt;br&gt;is unknown, please give the owner&apos;s name</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="213"/>
+        <location filename="../ownedUsbDisk.py" line="200"/>
         <source>Entrer un nom</source>
         <translation>Enter a name</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="430"/>
+        <location filename="../mainWindow.py" line="424"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation>You will erase many drives</translation>
     </message>
@@ -416,7 +416,7 @@ p, li { white-space: pre-wrap; }
         <translation>Add a filename or a filter defined in the edit line</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="555"/>
+        <location filename="../mainWindow.py" line="549"/>
         <source>Réitérer la dernière commande</source>
         <translation>Redo the last command</translation>
     </message>
@@ -616,7 +616,7 @@ p, li { white-space: pre-wrap; }
         <translation>Failed to open students&apos; file</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="212"/>
+        <location filename="../ownedUsbDisk.py" line="199"/>
         <source>La cle {id}&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
         <translation>The drive {id}&lt;br&gt;is not identified, give the owner&apos;s name</translation>
     </message>
@@ -631,12 +631,12 @@ p, li { white-space: pre-wrap; }
         <translation>{t} seconds</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="282"/>
+        <location filename="../mainWindow.py" line="276"/>
         <source>pas d&apos;action pour l&apos;attribut {a}</source>
         <translation>No action for attribute {a}</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="555"/>
+        <location filename="../mainWindow.py" line="549"/>
         <source>La dernière commande était&lt;br&gt;{cmd}&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
         <translation>Last command was&lt;br&gt;{cmd}&lt;br&gt;Do you want to lauch it again with the new drives?</translation>
     </message>
@@ -731,32 +731,32 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="423"/>
+        <location filename="../mainWindow.py" line="417"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="485"/>
+        <location filename="../mainWindow.py" line="479"/>
         <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="479"/>
+        <location filename="../mainWindow.py" line="473"/>
         <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="480"/>
+        <location filename="../mainWindow.py" line="474"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="493"/>
+        <location filename="../mainWindow.py" line="487"/>
         <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="524"/>
+        <location filename="../mainWindow.py" line="518"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -814,7 +814,7 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Version #%1.%2</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="806"/>
+        <location filename="../mainWindow.py" line="773"/>
         <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
         <translation>Check or uncheck this box bi a click&lt;br&gt;&lt;b&gt;Double click&lt;/b&gt; to modifiy several media.</translation>
     </message>
@@ -824,42 +824,42 @@ p, li { white-space: pre-wrap; }
         <translation>Version number {major}.{minor}</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="589"/>
+        <location filename="../mainWindow.py" line="583"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="589"/>
+        <location filename="../mainWindow.py" line="583"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="808"/>
+        <location filename="../mainWindow.py" line="775"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="810"/>
+        <location filename="../mainWindow.py" line="777"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="812"/>
+        <location filename="../mainWindow.py" line="779"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="814"/>
+        <location filename="../mainWindow.py" line="781"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="816"/>
+        <location filename="../mainWindow.py" line="783"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="818"/>
+        <location filename="../mainWindow.py" line="785"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -962,12 +962,12 @@ p, li { white-space: pre-wrap; }
         <translation>Preferences</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="203"/>
+        <location filename="../mainWindow.py" line="200"/>
         <source>Refaire à nouveau</source>
         <translation>Redo last command</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="204"/>
+        <location filename="../mainWindow.py" line="201"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation>Redo the last successful command, with newly connected medias</translation>
     </message>
@@ -992,22 +992,22 @@ p, li { white-space: pre-wrap; }
         <translation>Delete files or directories in selected medias</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="205"/>
+        <location filename="../mainWindow.py" line="202"/>
         <source>Arrêter les opérations en cours</source>
         <translation>Stop ongoing operations</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="206"/>
+        <location filename="../mainWindow.py" line="203"/>
         <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
         <translation>Try to stop ongoing operations. To do only if they are too slow</translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="81"/>
+        <location filename="../mainWindow.py" line="79"/>
         <source>&lt;br /&gt;Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez</source>
         <translation>&lt;br /&gt;Names are availble to rename next drives you will plug in</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="82"/>
+        <location filename="../mainWindow.py" line="80"/>
         <source>&lt;br /&gt;Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez</source>
         <translation>&lt;br /&gt;Click on this button to prepare a list of names to rename drives you will plug in later</translation>
     </message>
@@ -1086,12 +1086,12 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>uDisk</name>
     <message>
-        <location filename="../usbDisk.py" line="65"/>
+        <location filename="../usbDisk.py" line="71"/>
         <source>point de montage</source>
         <translation>Mount point</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="66"/>
+        <location filename="../usbDisk.py" line="72"/>
         <source>taille</source>
         <translation>Size</translation>
     </message>
@@ -1111,27 +1111,27 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Serial number</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="72"/>
+        <location filename="../usbDisk.py" line="78"/>
         <source>cocher</source>
         <translation>Check</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="154"/>
+        <location filename="../ownedUsbDisk.py" line="152"/>
         <source>owner</source>
         <translation>Owner</translation>
     </message>
     <message>
-        <location filename="../usbDisk.py" line="67"/>
+        <location filename="../usbDisk.py" line="73"/>
         <source>marque</source>
         <translation>vendor</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="68"/>
+        <location filename="../usbDisk.py" line="74"/>
         <source>modèle de disque</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../usbDisk.py" line="69"/>
+        <location filename="../usbDisk.py" line="75"/>
         <source>numéro de série</source>
         <translation type="unfinished"></translation>
     </message>
