@@ -26,7 +26,7 @@ licence['en']=licence_en
 dependences="python3-dbus python3-dbus.mainloop.qt"
 python3safe="True"
 
-import dbus, subprocess, os.path, re, time
+import dbus, subprocess, os, os.path, re, time, threading
 from PyQt4.QtGui import *
 
 
@@ -39,25 +39,31 @@ class uDisk:
     - \b device l'objet dbus qui correspond à l'instance
     - \b device_prop un proxy pour questionner cet objet dbus
     - \b selected booléen vrai si on doit considérer cette instance comme sélectionnée. Vrai à l'initialisation
-    - \b checkable booléen vrai si on veut que la sélection puisse être modifiée par l'utilisateur dans l'interface graphique
+    - \b rlock un verrou récursif permettant de réserver l'usage du media pour un seul thread
     """
 
-    def __init__(self, path, bus, checkable=False):
+    def __init__(self, path, bus):
         """
         Le constructeur
         @param path un chemin dans le système dbus
         @param bus un objet dbus.BusSystem
-        @param checkable vrai si on fera usage de self.selected
         """
         self.path=path
+        self.mp=None # a variable to cache the result of self.mountPoint()
         self.device = bus.get_object("org.freedesktop.UDisks", self.path)
         self.device_prop = dbus.Interface(self.device, "org.freedesktop.DBus.Properties")
         self.selected=True
-        self.checkable=checkable
+        self.rlock=threading.RLock()
         self.stickid=self.getProp("drive-serial")
         self.uuid=self.getProp("id-uuid")
         self.fatuuid=None  # pour l'uuid de la première partion vfat
         self.firstFat=None # poignée de la première partition vfat
+        p=self.file()
+        # self.devStuff is the name of device which is usable to umount safely this object
+        if p:
+            self.devStuff=os.path.abspath(os.path.join(os.path.dirname(p), os.readlink(p)))
+        else:
+            self.devStuff=None
         #
 
             
@@ -89,21 +95,16 @@ class uDisk:
         """
         return self.file()
         
-    def headers(checkable=False,locale="C"):
+    def headers(locale="C"):
         """
         Méthode statique, pour avoir des titres de colonne.
-        renvoie des titres pour les items obtenus par __getitem__. Le
-        résultat dépend du paramètre checkable.
-        @param checkable vrai si le premier en-tête correspond à une colonne de cases à cocher
+        renvoie des titres pour les items obtenus par __getitem__. 
         @param locale la locale, pour traduire les titres éventuellement.
         Valeur par défaut : "C"
         @return une liste de titres de colonnes
         """
-        if checkable:
-            result= list(uDisk._specialItems.keys())+ list(uDisk._itemNames.keys())
-            return sorted(result)
-        else:
-            return sorted(uDisk._itemNames.keys())
+        result= list(uDisk._specialItems.keys())+ list(uDisk._itemNames.keys())
+        return sorted(result)
         
     headers = staticmethod(headers)
     
@@ -155,19 +156,26 @@ class uDisk:
         à l'instance.
         """
         fileByPath=self.getProp("device-file-by-path")
-        if isinstance(fileByPath, dbus.Array): fileByPath=fileByPath[0]
-        return fileByPath
+        if isinstance(fileByPath, dbus.Array) and len(fileByPath)>0:
+            fileByPath=fileByPath[0]
+            return fileByPath
+        else:
+            return None
     
     def mountPoint(self):
         """
         Permet d'accèder à l'instance par un point de montage
         @return un point de montage, s'il en existe, sinon None
         """
-        paths=self.getProp("device-mount-paths")
-        if isinstance(paths, dbus.Array) and len(paths)>0:
-            return paths[0]
+        if self.mp==None:
+            paths=self.getProp("device-mount-paths")
+            if isinstance(paths, dbus.Array) and len(paths)>0:
+                self.mp=paths[0]
+                return paths[0]
+            else:
+                return None
         else:
-            return None
+            return self.mp
     
     def getProp(self, name):
         """
@@ -237,6 +245,7 @@ class uDisk:
                     r+=prefix+"%s = %s G" %(prop,p/1024/1024/1024)
             else:
                 r+=prefix+"%s = %s" %(prop,p)
+        r+=prefix+"%s = %s" %('devStuff', self.devStuff)
         return r
 
     def master(self):
@@ -265,18 +274,15 @@ class uDisk:
         """
         Renvoie un élément de listage de données internes au disque
         @param n un nombre
-        @param checkable vrai si on doit renvoyer une propriété supplémentaire pour n==0
-        @return si checkable est vrai, un élément si n>0, et le drapeau self.selected si n==0 ; sinon un élément de façon ordinaire. Les noms des éléments sont dans la liste itemNames utilisée dans la fonction statique headers
+        @return un élément si n>0, et le drapeau self.selected si n==0. 
+        Les noms des éléments sont dans la liste itemNames utilisée dans 
+        la fonction statique headers
         """
         propListe=self.headers()
-        if self.checkable:
-            if n==0:
-                return self.selected
-            elif n <= len(propListe):
-                return self.unNumberProp(n-1)
-        else:
-            if n < len(propListe):
-                return self.unNumberProp(n)
+        if n==0:
+            return self.selected
+        elif n <= len(propListe):
+            return self.unNumberProp(n-1)
 
     def showableProp(self, name):
         """
@@ -340,7 +346,6 @@ class Available:
     une classe pour représenter la collection des disques USB connectés
 
     les attributs publics sont :
-    - \b checkable booléen vrai si on veut gérer des sélections de disques
     - \b access le type d'accès qu'on veut pour les items
     - \b bus une instance de dbus.SystemBus
     - \b disks la collection de disques USB, organisée en un dictionnaire
@@ -350,18 +355,15 @@ class Available:
     - \b firstFats une liste composée de la première partion DOS-FAT de chaque disque USB.
     """
 
-    def __init__(self, checkable=False, access="disk", diskClass=uDisk, diskDict=None):
+    def __init__(self,access="disk", diskClass=uDisk, diskDict=None):
         """
         Le constructeur
-        @param checkable : vrai si on veut pouvoir cocher les disques de la
-          collection. Faux par défaut.
         @param access définit le type d'accès souhaité. Par défaut, c'est "disk"
           c'est à dire qu'on veut la liste des disques USB. Autres valeurs
           possibles : "firstFat" pour les premières partitions vfat.
         @param diskClass la classe de disques à créer
         @param diskDict un dictionnaire des disque maintenu par deviceListener
         """
-        self.checkable=checkable
         self.access=access
         self.bus = dbus.SystemBus()
         proxy = self.bus.get_object("org.freedesktop.UDisks", 
@@ -371,7 +373,7 @@ class Available:
         self.enumDev=iface.EnumerateDevices()
         ### récupération des disques usb dans le dictionnaire self.disks
         for path in self.enumDev:
-            ud=diskClass(path, self.bus, checkable)
+            ud=diskClass(path, self.bus)
             if ud.isUsbDisk():
                 self.disks[ud]=[]
                 # cas des disques sans partitions
@@ -381,7 +383,7 @@ class Available:
                     self.disks[ud].append(ud)
         ### une deuxième passe pour récupérer et associer les partitions
         for path in self.enumDev:
-            ud=diskClass(path, self.bus, checkable)
+            ud=diskClass(path, self.bus)
             for d in self.disks.keys():
                 if ud.master() == d.path:
                     self.disks[d].append(ud)
